. ./config.txt
SCRIPT_DIR=./script
WORK_DIR=$1
# 1. Prepare data for the classifier
echo "1. Prepare data for the classifier"

# suppose that we are using 50 (usually 5,000) zh and ja parallel sentence in $WORK_DIR
# which have been segmented (zh.para, ja.para) and pos tagged (zh.para.pos, ja.para.pos)

# 1.1 generate negative instances (comparable sentences) for the classifer
echo "1.1 generate negative instances (comparable sentences) for the classifer"
# generate by cartesian product, for zh & ja, it uses both sentence ratio and common Chinese characters 
# to filter sentences that are too noisy, for other language pairs, it simply uses a sentence ratio filter
perl $SCRIPT_DIR/cartesian_filter.pl -data_path $WORK_DIR

# randomly discard some negative instances for training when necessary to guarantee that 
# the ratio of negative to positive instances is less than five for the performance of the classifier
n_time=5
perl $SCRIPT_DIR/random4comp.pl -data_path $WORK_DIR -n_time $n_time

# generate the pos tags for the negative instances
perl $SCRIPT_DIR/gen_comp_pos.pl -data_path $WORK_DIR

# 1.2 word alignment of the parallel and comparable sentences
echo "1.2 word alignment of the parallel and comparable sentences"
# prepare alignment data:
mkdir -p alignment/data
cat $WORK_DIR/zh.para | perl $SCRIPT_DIR/moses_format.pl > alignment/data/data.fr
cat $WORK_DIR/zh.comp | perl $SCRIPT_DIR/moses_format.pl >> alignment/data/data.fr
cat $WORK_DIR/ja.para | perl $SCRIPT_DIR/moses_format.pl > alignment/data/data.en
cat $WORK_DIR/ja.comp | perl $SCRIPT_DIR/moses_format.pl >> alignment/data/data.en

# alignment
mkdir -p alignment/tm
cd alignment/tm && \
nice -15 $MOSES_SCRIPTS_DIR_SHARE/training/train-model.perl --external-bin-dir $MGIZA_BIN_DIR -corpus ../data/data -f fr -e en \
     -alignment grow-diag-final-and -giza-option "nodumps=0,onlyaldumps=0" --alignment-factors 1-1 --factor-delimiter "=|=" \
     --parallel --last-step 4 -mgiza -mgiza-cpus 8 2> /dev/null > /dev/null \
&& cd ../../

# alignment results for the positive and negative instances
PARA_SEN_NUM=`wc -l $WORK_DIR/zh.para | sed -e 's/ .*//g'`
COMP_SEN_NUM=`wc -l $WORK_DIR/zh.comp | sed -e 's/ .*//g'`
head -$PARA_SEN_NUM alignment/tm/model/aligned.grow-diag-final-and > $WORK_DIR/align.para
tail -$COMP_SEN_NUM alignment/tm/model/aligned.grow-diag-final-and > $WORK_DIR/align.comp

rm -rf alignment
