#!/usr/bin/env perl

# Kanji2SC.pm
# author: Chu Chenhui(Kyoto University)
# email: chu@nlp.ist.i.kyoto-u.ac.jp
# date: 2011/10/20

# Discription: this module convert Kanji to Simplified Chinese

package Kanji2SC;

use strict;
use utf8;

# mapping table
my %kanji_SC_hash;

my $mapping_file = "../dic/all_com_mapping.txt";
open(IN_MAPPING, "<:utf8", $mapping_file);
while(<IN_MAPPING>) {
    chomp;
    my @char_array = split(/\t/, $_);
    
    my $kanji = $char_array[0];

    my @sc_array;
    if($char_array[2] !~ /N\/A/) {
	@sc_array = split(/,/, $char_array[2]);
    }

    $kanji_SC_hash{$kanji} = \@sc_array;
}
close IN_MAPPING;

# Kanji to SC
# var: Kanji
# return: SC array
sub conv_j2c {
    my ($kanji) = @_;

    my @sc_array;
    # exist conversion result
    if($kanji_SC_hash{$kanji}) {
	@sc_array = @{$kanji_SC_hash{$kanji}};
    } 
    # no conversion result, return itself
    if(!@sc_array) {
	push(@sc_array, $kanji);
    }

    return @sc_array;
}

# Kanji word to SC word
# var: Kanji word 
# return: Kanji word array
sub conv_j2c_word {
    my ($kanji_word) = @_;

    my @kanji_array = $kanji_word =~ /./g;

    my @word_sc_cand_array;
    my $count = 1;
    foreach my $kanji (@kanji_array) {
 
	my @sc_array = &conv_j2c($kanji);
    
	my @temp_array = @word_sc_cand_array;
	@word_sc_cand_array = ();
	if($count == 1) {
	    foreach my $sc (@sc_array) {
		push(@word_sc_cand_array, $sc);
	    }
	} else {
	    foreach my $temp (@temp_array) {
		foreach my $sc (@sc_array) {
		    my $word_sc_cand = $temp . $sc;
		    push(@word_sc_cand_array, $word_sc_cand);
		}
	    }
	}
	$count++;
    }

    return @word_sc_cand_array;
}

1;
