#!/usr/bin/env perl

# Util.pm
# author: Chu Chenhui(Kyoto University)
# email: chu@nlp.ist.i.kyoto-u.ac.jp
# date: 2013/02/28

# Discription: this module contains common funtcions

package Util;

use strict;
use utf8;
use Encode;
use Unicode::Japanese;

use lib './';
use Kanji2SC;

sub read_file {
    my ($file) = @_;
    my @line_array;
    open(IN, "<:utf8", $file) or die "cannot open < $file!";
    while(<IN>) {
	chomp;
	push(@line_array, $_);
    }
    close IN;
    return @line_array;
}

sub read_file_into_array {
    my ($file, $line_array) = @_;
    open(IN, "<:utf8", $file);
    while(<IN>) {
	chomp;
	push(@$line_array, $_);
    }
    close IN;
}

sub read_LEX {
    my ($LEX_file, $LEX_hash) = @_;
    my @LEX_array = &read_file("$LEX_file");
    foreach my $LEX_sen (@LEX_array) {
	my ($word_1, $word_2, $prob) = split(/ /, $LEX_sen);
	$$LEX_hash{$word_1}{$word_2} = $prob;
    }
}

sub random {
    my ($threshold, $generate_num) = @_;

    my %rand_hash;
    while(scalar(keys %rand_hash) < $generate_num) {
	my $rand_num = int(rand($threshold));
	$rand_hash{$rand_num}++;
    }

    return %rand_hash;
    # my @rand_array;
    # foreach my $key (keys %rand_hash) {
    # 	push(@rand_array, $key);
    # }

    # return @rand_array;
}

sub output_hash {
    my ($hash_var, $opt) = @_;
    my %hash = %$hash_var;
    # sort key
    if($opt == 1) {
	foreach my $key (sort {$a <=> $b} keys %hash) {
	    print "$key, $hash{$key}\n";
	}
    }
    # sort value
    elsif($opt == 2) {
	foreach my $key (sort {$hash{$a} <=> $hash{$b}} keys %hash) {
	    print "$key, $hash{$key}\n";
	}
    } else {
	foreach my $key (keys %hash) {
	    print "$key, $hash{$key}\n";
	}
    }
}

sub output_array {
    my ($array) = @_;

    foreach my $val (@$array) {
	print "$val\n";
    }
}

sub h2z {
    my ($str) = @_;
    my $str = Unicode::Japanese->new($str)->h2z->get;
    $str = decode('utf8', $str);
}

sub generate_prefix {
    my ($total_num, $cur_num) = @_;
    my $zero_num = length($total_num) - length($cur_num);
    my $prefix;
    while($zero_num-- > 0) {
	$prefix .= '0';
    }
    $prefix .= $cur_num;
    return $prefix;
}

sub kanji_match {
    my ($word_zh, $word_ja) = @_;

    my @char_array = $word_ja =~ /./g;
    my $char_array_len = @char_array;
    my @kanji_array = $word_ja =~ /\p{Han}/g;
    my $kanji_array_len = @kanji_array;

    my $is_matched = 0;
    # for kanji word
    if($char_array_len == $kanji_array_len) {
	my @word_sc_cand_array = Kanji2SC::conv_j2c_word($word_ja);
	foreach my $word_sc_cand (@word_sc_cand_array) {
	    if($word_sc_cand eq $word_zh) {
		$is_matched = 1;
		last;
	    }
	}
    }

    return $is_matched;
}

sub wc {
    my ($file) = @_;
    my $line_num;
    my $line_info = `wc -l $file`;
    if($line_info =~ /(.*?) .*/) {
    	$line_num = $1;
    }
    return $line_num;
}

1;
