# !/usr/bin/env perl

# eval_libsvm.pl
# date: 2013/06/26

# Discription: evaluate classifer accuracy for LIBSVM output

use strict;
use utf8;
use Getopt::Long;
use lib './script';
use Util;

binmode STDIN, ":utf8";
binmode STDOUT, ":utf8";
binmode STDERR, ":utf8";

my (%opt); GetOptions(\%opt, 'svm_path=s', 'threshold=f', 'data_path=s');

my $svm_path = $opt{svm_path};
my $THRESHOLD = $opt{threshold};
my $data_path = $opt{data_path};

my $event_file = "$svm_path/test";
my $ja_para_file = "$data_path/ja.para";
my $zh_para_file = "$data_path/zh.para";
my $ja_comp_file = "$data_path/ja.comp";
my $zh_comp_file = "$data_path/zh.comp";

my @event_array = Util::read_file($event_file);
my @ja_para_array = Util::read_file($ja_para_file);
my @zh_para_array = Util::read_file($zh_para_file);
my @ja_comp_array = Util::read_file($ja_comp_file);
my @zh_comp_array = Util::read_file($zh_comp_file);

my $true_parallel = Util::wc($ja_para_file);

# read result file
my $result_file = "$svm_path/test.predict";
open(IN_RESULT, "<:utf8", $result_file);
# output error file
my $error_file = "$svm_path/test.error";
open(OUT_ERR, ">:utf8", $error_file);

my $result_line = 0;
my $classified_well = 0;
my $classified_parallel = 0;
while(<IN_RESULT>) {
    chomp;
    if($result_line == 0) {
	$result_line++;
	next;
    }

    my $result = $_;
    my @result_array = split(/ /, $result);

    # my $is_parallel = $result_array[0];
    # if($is_parallel == 1) {

    my $prob = $result_array[1];
    if($prob >= $THRESHOLD) {
	if($result_line <= $true_parallel) {
	    $classified_well++;
	    $classified_parallel++;

	    # print OUT_ERR "Turely parallel:$result_line, $result\n";
	    # print OUT_ERR "$ja_para_array[$result_line-1]\n";
	    # print OUT_ERR "$zh_para_array[$result_line-1]\n";
	    # print OUT_ERR "$event_array[$result_line-1]\n";
	} else {
	    $classified_parallel++;

	    print OUT_ERR "Falsely parallel:$result_line, $result\n";
	    print OUT_ERR "$ja_comp_array[$result_line-$true_parallel-1]\n";
	    print OUT_ERR "$zh_comp_array[$result_line-$true_parallel-1]\n";
	    print OUT_ERR "$event_array[$result_line-1]\n";
	}
    } else {
	if($result_line <= $true_parallel) {
	    # print OUT_ERR "Falsely comparable:$result_line, $result\n";
	    # print OUT_ERR "$ja_para_array[$result_line-1]\n";
	    # print OUT_ERR "$zh_para_array[$result_line-1]\n";
	    # print OUT_ERR "$event_array[$result_line-1]\n";
	}
    }
    $result_line++;
}
close IN_RESULT;
close OUT_ERR;

my $precision = 100 * ($classified_well / $classified_parallel);
my $recall = 100 * ($classified_well / $true_parallel);
#my $f = 100 * ((2 * $classified_well) / ($classified_parallel + $true_parallel));
my $f = 2 * (($precision * $recall) / ($precision + $recall));
print "classified_well: $classified_well, classified_parallel: $classified_parallel, true_parallel: $true_parallel\n";
printf "precision: %3.2f, recall: %3.2f, f-value: %3.2f\n", $precision, $recall, $f;
