# !/usr/bin/env perl

# extract_classified_pos.pl
# date: 2013/07/30

# Discription: this script extracts parallel sentences from classifiled pos results

use strict;
use utf8;
use Getopt::Long;
use lib './script';
use Util;

binmode STDIN, ":utf8";
binmode STDOUT, ":utf8";
binmode STDERR, ":utf8";

my (%opt); GetOptions(\%opt, 'comp_path=s', 'predict_file=s', 'threshold=f', 'output_path=s');

my $comp_path = $opt{comp_path};
my $predict_file = $opt{predict_file};
my $THRESHOLD = $opt{threshold};
my $output_path = $opt{output_path};

my $ja_comp_file = "$comp_path/ja.pos";
my $zh_comp_file = "$comp_path/zh.pos";
my $out_ja_file = "$output_path/ja.extr.$THRESHOLD";
my $out_zh_file = "$output_path/zh.extr.$THRESHOLD";
my $out_prob_file = "$output_path/prob.extr.$THRESHOLD";

my @ja_line_array;
my @zh_line_array;

# read en/ja sentences from comparable data
Util::read_file_into_array("$ja_comp_file", \@ja_line_array);
# read zh sentences from comparable data
Util::read_file_into_array("$zh_comp_file", \@zh_line_array);

# output ja data
open(OUT_JA, ">:utf8", $out_ja_file);
# output zh data
open(OUT_ZH, ">:utf8", $out_zh_file);
# output probability
open(OUT_PROB, ">:utf8", $out_prob_file);
# read classification result data
open(IN_RES, "<:utf8", $predict_file);
my $line_num = 0;
while(<IN_RES>) {
    chomp;
    if($line_num == 0) {
	$line_num++;
	next;
    }
    my $result = $_;
    my @result_array = split(/ /, $result);

    # my $is_parallel = $result_array[0];
    # if($is_parallel == 1) {

    my $prob = $result_array[1];
    if($prob >= $THRESHOLD) {
    	my $zh_text = $zh_line_array[$line_num-1];
    	my $ja_text = $ja_line_array[$line_num-1];

	my @word_zh_space_array = split(/ /, $zh_text);
	my $sen_zh_line;
	foreach my $word_zh_space (@word_zh_space_array) {
	    my ($word_zh, $pos_zh) = split(/\_/, $word_zh_space);
	    $sen_zh_line .= $word_zh;
	    $sen_zh_line .= ' ';
	}
	$sen_zh_line =~ s/\s\Z//g;

	my @word_ja_space_array = split(/ /, $ja_text);
	my $sen_ja_line;
	foreach my $word_ja_space (@word_ja_space_array) {
	    my ($word_ja, $pos_ja, $sub_pos_ja) = split(/\:/, $word_ja_space);
	    $sen_ja_line .= $word_ja;
	    $sen_ja_line .= ' ';
	}
	$sen_ja_line =~ s/\s\Z//g;

    	print OUT_ZH "$sen_zh_line\n";
    	print OUT_JA "$sen_ja_line\n";
    	print OUT_PROB "$prob\n";
    }

    $line_num++;
}
close IN_RES;
close OUT_ZH;
close OUT_JA;
close OUT_PROB;
