# !/usr/bin/env perl

# gen_comp_pos.pl
# date: 2013/07/08

# Discription: generate comparable sentence pairs with POS-tags

use strict;
use utf8;
use Getopt::Long;
use lib '/home/chu/tools/perl-module';
use Util;

binmode STDIN, ":utf8";
binmode STDOUT, ":utf8";
binmode STDERR, ":utf8";

my (%opt); GetOptions(\%opt, 'data_path=s');
my $data_path = $opt{data_path};

&main();

sub main {
    my %ja_pos_hash;
    my $ja_para_file = "$data_path/ja.para";
    my $ja_para_pos_file = "$data_path/ja.para.pos";
    &gen_pos_hash($ja_para_file, $ja_para_pos_file, \%ja_pos_hash);

    my %zh_pos_hash;
    my $zh_para_file = "$data_path/zh.para";
    my $zh_para_pos_file = "$data_path/zh.para.pos";
    &gen_pos_hash($zh_para_file, $zh_para_pos_file, \%zh_pos_hash);

    my $ja_comp_file = "$data_path/ja.comp";
    my $zh_comp_file = "$data_path/zh.comp";
    my $ja_comp_pos_file = "$data_path/ja.comp.pos";
    my $zh_comp_pos_file = "$data_path/zh.comp.pos";
    open(IN_JA_COMP, "<:utf8", $ja_comp_file);
    open(IN_ZH_COMP, "<:utf8", $zh_comp_file);
    open(OUT_JA_COMP_POS, ">:utf8", $ja_comp_pos_file);
    open(OUT_ZH_COMP_POS, ">:utf8", $zh_comp_pos_file);
    while(my $ja_comp = <IN_JA_COMP>) {
	my $zh_comp = <IN_ZH_COMP>;
	chomp($ja_comp);
	chomp($zh_comp);
	print OUT_JA_COMP_POS "$ja_pos_hash{$ja_comp}\n";
	print OUT_ZH_COMP_POS "$zh_pos_hash{$zh_comp}\n";
    }
    close IN_JA_COMP;
    close IN_ZH_COMP;
    close OUT_JA_COMP_POS;
    close OUT_ZH_COMP_POS;
}

sub gen_pos_hash {
    my ($para_file, $para_pos_file, $pos_hash) = @_;
    open(IN_PARA, "<:utf8", $para_file);
    open(IN_PARA_POS, "<:utf8", $para_pos_file);
    while(my $para = <IN_PARA>) {
	my $para_pos = <IN_PARA_POS>;
	chomp($para);
	chomp($para_pos);
	$$pos_hash{$para} = $para_pos;
    }
    close IN_PARA;
    close IN_PARA_POS;
}
