# !/usr/bin/env perl

# random4comp.pl
# date: 2013/06/25

# Discription: randomly select comparable data 
# (parallel number * n times) as negateive instances

use strict;
use utf8;
use Getopt::Long;
use lib './script';
use Util;

binmode STDIN, ":utf8";
binmode STDOUT, ":utf8";
binmode STDERR, ":utf8";

my (%opt); GetOptions(\%opt, 'data_path=s', 'n_times=i');

my $data_path = $opt{data_path};
my $n_times = $opt{n_times};

&main();

sub main {
    my $zh_para_file = "$data_path/zh.para";
    my $zh_comp_file = "$data_path/zh.cartesian.filter";
    my $ja_comp_file = "$data_path/ja.cartesian.filter";
    my $zh_rand_file = "$data_path/zh.comp";
    my $ja_rand_file = "$data_path/ja.comp";

    my $parallel_num = Util::wc($zh_para_file);
    my $comparable_num = Util::wc($zh_comp_file);
    my $generate_num = $n_times * $parallel_num;

    if($comparable_num < $generate_num) {
	my $zh_cp = `cp $zh_comp_file $zh_rand_file`;
	my $ja_cp = `cp $ja_comp_file $ja_rand_file`;
    } else {
	my %rand_hash = Util::random($comparable_num, $generate_num);

	open(IN_ZH_COMP, "<:utf8", $zh_comp_file);
	open(IN_JA_COMP, "<:utf8", $ja_comp_file);
	open(OUT_ZH_RAND, ">:utf8", $zh_rand_file);
	open(OUT_JA_RAND, ">:utf8", $ja_rand_file);
	my $line_num = 0;
	while(my $zh_comp = <IN_ZH_COMP>) {
	    my $ja_comp = <IN_JA_COMP>;
	    chomp($zh_comp);
	    chomp($ja_comp);
	    if($rand_hash{$line_num}) {
		print OUT_ZH_RAND "$zh_comp\n";
		print OUT_JA_RAND "$ja_comp\n";
	    }
	    $line_num++;
	}
	close IN_ZH_COMP;
	close IN_JA_COMP;
	close OUT_ZH_RAND;
	close OUT_JA_RAND;
    }
}
